pyS5p
=====

pyS5p provides a Python interface to S5p Tropomi Level-1B (and 2) products.

Note that all plotting S/W has been moved to moniplot:

* https://github.com/rmvanhees/moniplot

For more information on the Sentinel 5 precursor mission visit:

* https://earth.esa.int/web/guest/missions/esa-future-missions/sentinel-5P
* http://www.tropomi.eu

For more information on the Tropomi Level-1B products visit:

* http://www.tropomi.eu/documents/level-0-1b-products

The software requires Python3.8+ and Python modules: h5py, numpy, matplotlib
